@@ -11,7 +11,7 @@ use File::Path;
 use XML::Simple;
 use Sys::Hostname;
 
-our $VERSION = '2.1.7';
+our $VERSION = '2.1.8';
 $ENV{LC_ALL} = 'C'; # Turn off localised output for commands
 $ENV{LANG} = 'C'; # Turn off localised output for commands
 
@@ -266,12 +266,13 @@ sub main {
         });
 
         my @tasks = qw/
-            Inventory
+            Deploy
             OcsDeploy
+            Inventory
             WakeOnLan
             SNMPQuery
             NetDiscovery
-            Ping
+            ESX
             /;
 
         foreach my $module (@tasks) {
