@@ -13,7 +13,7 @@ sub doInventory {
 
 # TODO: This had been rewrite from the Linux agent _WITHOUT_ being checked!
     foreach (`equery list -i`){
-        if (/^([a-z]\w+-\w+\/\w+)-([0-9]+.*)/) {
+        if (/^(.*)-([0-9]+.*)/) {
             $inventory->addSoftware({
                 'NAME'          => $1,
                 'VERSION'       => $2,
