@@ -23,6 +23,7 @@ use XML::Simple;
 use Digest::MD5 qw(md5_base64);
 use Config;
 
+use FusionInventory::Agent;
 use FusionInventory::Agent::Task::Inventory;
 
 =over 4
@@ -72,7 +73,7 @@ sub new {
     $self->{h}{CONTENT}{USBDEVICES} = [];
     $self->{h}{CONTENT}{BATTERIES} = [];
     $self->{h}{CONTENT}{ANTIVIRUS} = [];
-    $self->{h}{CONTENT}{VERSIONCLIENT} = ['FusionInventory-Agent_v'.$config->{VERSION}];
+    $self->{h}{CONTENT}{VERSIONCLIENT} = ['FusionInventory-Agent_v'.$FusionInventory::Agent::VERSION];
 
     # Is the XML centent initialised?
     $self->{isInitialised} = undef;
@@ -294,6 +295,7 @@ sub addStorage {
         SCSI_CHID
         SCSI_UNID
         SCSI_LUN
+	WWN
     /;
 
     my $values = $args;
@@ -301,6 +303,13 @@ sub addStorage {
         $values->{SERIALNUMBER} = $values->{SERIAL}
     }
 
+    my $filter = '^(SCSI|HDC|IDE|USB|1394|Serial-ATA|SAS)$';
+    if ($values->{INTERFACE} && $values->{INTERFACE} !~ /$filter/) {
+        $logger->debug("STORAGES/INTERFACE doesn't match /$filter/, ".
+        "this is not an error but the situation should be improved");
+    }
+
+
     $self->_addEntry({
         'field' => \@fields,
         'sectionName' => 'STORAGES',
@@ -562,6 +571,8 @@ sub addNetwork {
         SLAVES
         SPEED
         MANAGEMENT
+        BSSID
+        SSID
     /;
 
 
@@ -782,6 +793,9 @@ sub addVirtualMachine {
         VMTYPE
         VCPU
         VMID
+        MAC
+        COMMENT
+        OWNER
     /;
 
     if (!$args->{STATUS}) {
@@ -1134,7 +1148,7 @@ sub writeHTML {
     </head>
     <body>
     <h1>Inventory for '.$target->{deviceid}.'</h1>
-    FusionInventory Agent '.$config->{VERSION}.'<br />
+    FusionInventory Agent '.$FusionInventory::Agent::VERSION.'<br />
     <small>DEVICEID '.$target->{deviceid}.'</small>
 
     ';
@@ -1438,10 +1452,16 @@ Windows CAPTION field or subsystem Name from the pci.ids table
 
 =item NAME
 
+The device name, the on from the PCIIDs DB
+
 =item MANUFACTURER
 
+The manifacturer name, the on from the PCIIDs DB
+
 =item PCICLASS
 
+The PCI class ID
+
 =item PCIID
 
 The PCI ID, e.g: 8086:2a40 (only for PCI device)
@@ -1517,6 +1537,8 @@ Number of core.
 
 =item MANUFACTURER
 
+AMD/Intel/Transmeta/Cyrix/VIA
+
 =item NAME
 
 The name of the CPU, e.g: Intel(R) Core(TM)2 Duo CPU     P8600  @ 2.40GHz
@@ -1553,7 +1575,7 @@ Date of creation of the filesystem in DD/MM/YYYY format.
 
 =item FREE
 
-Free space
+Free space (MB)
 
 =item FILESYSTEM
 
@@ -1577,7 +1599,7 @@ Boolean. Is this the system partition?
 
 =item TOTAL
 
-Total space available.
+Total space available (MB)
 
 =item TYPE
 
@@ -1585,7 +1607,7 @@ The mount point on UNIX.
 
 =item VOLUMN
 
-System name of the partition (e.g: /dev/sda1)
+System name of the partition (e.g: /dev/sda1 or server:/directory for NFS)
 
 =back
 
@@ -1638,8 +1660,12 @@ The time needed to run the inventory on the agent side.
 
 =item DESCRIPTION
 
+Computer description (Windows only so far)
+
 =item MEMORY
 
+Total system memory in MB
+
 =item UUID
 
 =item DNS
@@ -1718,6 +1744,10 @@ Serial, Parallel, SATA, etc
 
 =head2 SLOTS
 
+Represents physical connection points including ports, motherboard slots and peripherals, and proprietary connection points.
+
+This information is hardly reliable.
+
 =over 4
 
 =item CAPACITY
@@ -1742,21 +1772,29 @@ Serial, Parallel, SATA, etc
 
 =item DESCRIPTION
 
+The long name of the device displayed to the user.
+
 =item DISKSIZE
 
 The disk size in MB.
 
 =item INTERFACE
 
+INTERFACE can be SCSI/HDC/IDE/USB/1394/Serial-ATA/SAS or empty if unknown
+
 =item MANUFACTURER
 
 =item MODEL
 
+The commercial name of the device
+
 =item NAME
 
+The name of the device as seen by the system. E.g: hda (Linux), \\.\PHYSICALDRIVE0 (Windows)
+
 =item TYPE
 
-INTERFACE can be SCSI/HDC/IDE/USB/1394/Serial-ATA
+The kind of device. There is no standard for the format of the string in this field.
 
 =item SERIAL
 
@@ -1776,6 +1814,10 @@ Deprecated. The harddrive serial number, same as SERIAL.
 
 =item SCSI_LUN
 
+=item WWN
+
+World Wide Name http://fr.wikipedia.org/wiki/World_Wide_Name
+
 =back
 
 =head2 SOFTWARES
@@ -1803,6 +1845,8 @@ Installation day in DD/MM/YYYY format. Windows only.
 
 =item NO_REMOVE
 
+Can the software be removed.
+
 =item RELEASE_TYPE
 
 Windows only for now, come from the registry
@@ -1898,10 +1942,22 @@ The name of the virtualisation system family. The same type found is HARDWARE/VM
 
 =item VCPU
 
+Number of CPU affected to the virtual machine
+
 =item VMID
 
 The ID of virtual machine in the virtual managment system.
 
+=item MAC
+
+The list of the MAC addresses of the virtual machine. The delimiter is '/'. e.g: 00:23:18:91:db:8d/00:23:57:31:sb:8e
+
+=item COMMENT
+
+a comment
+
+=item OWNER
+
 =back
 
 =head2 SOUNDS
@@ -1986,18 +2042,26 @@ The name of the device (optional)
 
 =head2 NETWORKS
 
+A network configuration.
+
 =over 4
 
 =item DESCRIPTION
 
+The name of the interface as seen in the OS settings, e.g: eth0 (Linux) or AMD PCNET Family Ethernet Adapter (Windows)
+
 =item DRIVER
 
+The name of the driver used by the network interface
+
 =item IPADDRESS
 
 =item IPADDRESS6
 
 =item IPDHCP
 
+The IP address of the DHCP server (optional).
+
 =item IPGATEWAY
 
 =item IPMASK
@@ -2010,10 +2074,16 @@ The name of the device (optional)
 
 =item PCISLOT
 
+The PCI slot name.
+
 =item STATUS
 
+Up or Down
+
 =item TYPE
 
+Interface type: Ethernet, Wifi
+
 =item VIRTUALDEV
 
 If the interface exist or not (1 or empty)
@@ -2030,6 +2100,14 @@ Whether or not it is a HP iLO, Sun SC, HP MP or other kind of Remote Management
 
 Interface speed in Mb/s
 
+=item BSSID
+
+Wifi only, Access point MAC Address
+
+=item SSID
+
+Wifi only, Access point name
+
 =back
 
 =head2 BATTERIES
